python - Wiktionary

# python

Definition from Wiktionary, the free dictionary
See also: Python

## English[edit]

Wikipedia has an article on:
python
Wikipedia
A python constricting a goat.

### Etymology[edit]

From Ancient Greek Πύθων ‎(Púthōn), the name of the mythological enormous serpent at Delphi slain by Apollo, from Πῡθώ ‎(Pūthṓ), the early name of Delphi, from πυθώ ‎(puthṓ, “to rot, to decay”).

### Pronunciation[edit]

- (UK) IPA(key): /ˈpaɪθən/
- (US) IPA(key): /ˈpaɪθɑːn/

### Noun[edit]

python ‎(plural pythons)

1. A type of large constricting snake.

#### Translations[edit]

constricting snake

Albanian: please add this translation if you can Armenian: պիթոն (hy) ‎(pitʿon) Basque: pitoi Belarusian: пітон m ‎(pitón) Binukid: bakesan Chinese: Mandarin: 蟒 (zh) ‎(mǎng), 巨蟒 (zh) ‎(jùmǎng), 蟒蛇 (zh) ‎(mǎngshé), 巨蛇 (zh) ‎(jùshé) Czech: krajta (cs) f Danish: pyton c Dupaninan Agta: iraw Dutch: python (nl) m Esperanto: pitono Finnish: pyton (fi) French: python (fr) m Galician: pitón f Georgian: please add this translation if you can German: Python (de) m, Pythonschlange f Greek: πύθωνας (el) m ‎(pýthonas) Hungarian: piton (hu), óriáskígyó (hu) Ido: (♂♀) pitono (io), (♂) pitonulo, (♀) pitonino, (♂♀ offspring) pitonyuno, (♂ offspring) pitonyunulo, (♀ offspring) pitonyunino Irish: píotón m1 Italian: pitone (it) m Japanese: ニシキヘビ ‎(nishiki-hebi), 錦蛇 (ja) ‎(にしきへび, nishiki-hebi) Khmer: please add this translation if you can |  | Kurdish: pîton (ku) Lithuanian: pitonas m, also smauglys m Lun Bawang: menelen Macedonian: питон m ‎(pitón), удав m ‎(údav) Manx: aarnieu traastey m Polish: pyton (pl) m Portuguese: pitão (pt) m Romanian: piton (ro) m, șarpe piton m Russian: пито́н (ru) m ‎(pitón) Serbo-Croatian: Cyrillic: питон m, удав m, боа f Roman: piton (sh) m, udav (sh) m, boa (sh) f Slovene: piton (sl) m Spanish: pitón (es) m Swahili: chatu (sw) Swedish: pytonorm c, pyton (sv) c Tagalog: sawa Telugu: కొండచిలువ (te) ‎(koṃḍaciluva) Thai: please add this translation if you can Turkish: piton (tr) Ukrainian: пітон m ‎(pitón) Vietnamese: trăn (vi) Volapük: (♂♀) pütonasnek, (♂) pütonahisnek, (♀) pütonajisnek, (♂♀ offspring) pütonasnekül, (♂ offspring) pütonahisnekül, (♀ offspring) pütonajisnekül, (♂♀) püton, (♂) hipüton, (♀) jipüton, (♂♀ offspring) pütonül, (♂ offspring) hipütonül, (♀ offspring) jipütonül

### Anagrams[edit]

- Typhon

## French[edit]

### Pronunciation[edit]

- IPA(key): /pi.tɔ̃/

### Noun[edit]

python m ‎(plural pythons)

1. python

### Anagrams[edit]

- typhon

### External links[edit]

- “python” in le Trésor de la langue française informatisé (The Digitized Treasury of the French Language).

## Interlingua[edit]

### Noun[edit]

python ‎(plural pythones)

1. python

## Latin[edit]

### Etymology[edit]

From the name of a snake slain at Delphi

### Pronunciation[edit]

- (Classical) IPA(key): /ˈpyː.tʰon/, [ˈpyː.tʰõ]

### Noun[edit]

pȳthon f ‎(genitive pȳthōnis); third declension

1. soothsayer

#### Inflection[edit]

Third declension.

Case | Singular | Plural
--- | --- | ---
nominative | pȳthon | pȳthōnēs
genitive | pȳthōnis | pȳthōnum
dative | pȳthōnī | pȳthōnibus
accusative | pȳthōnem | pȳthōnēs
ablative | pȳthōne | pȳthōnibus
vocative | pȳthon | pȳthōnēs

Retrieved from "https://en.wiktionary.org/w/index.php?title=python&oldid=40727472"
Categories:

- English terms derived from Ancient Greek
- English terms with IPA pronunciation
- English lemmas
- English nouns
- English countable nouns
- en:Snakes
- French terms with IPA pronunciation
- French lemmas
- French nouns
- French masculine nouns
- French countable nouns
- fr:Snakes
- Interlingua lemmas
- Interlingua nouns
- Latin terms with IPA pronunciation
- Latin lemmas
- Latin nouns
- Latin feminine nouns
- Latin third declension nouns
- Latin feminine nouns in the third declension

Hidden categories:

- etyl cleanup/en
- Ancient Greek redlinks
- Ancient Greek redlinks/m
- Translation requests (Albanian)
- Translation requests (Georgian)
- Translation requests (Khmer)
- Terms with manual transliterations different from the automated ones
- Terms with manual transliterations different from the automated ones/te
- Translation requests (Thai)
- French nouns with missing plurals
- Kenny's testing category